@@ -15,4 +15,7 @@ def growth_rate_plots():
     x.single_cell_growth()
     plot.growth_rate_div(x.single_cell_biomass)
     plot.growth_rate_time(x.single_cell_biomass)
-    plot.growth_rate_mu(x.single_cell_biomass)
\ No newline at end of file
+    plot.growth_rate_mu(x.single_cell_biomass)
+def plot_colonies():
+    f, ax = plt.subplots()
+    plot.plot_colony(x,time=100)
